# Canvy

<!--toc:start-->
- [Canvy](#canvy)
  - [Features](#features)
  - [Usage](#usage)
  - [Installation](#installation)
  - [Contribution](#contribution)
<!--toc:end-->

All-in-one manager for _educational resources_ hosted on **Canvas**.

## Features

- Download all resources (e.g. files, text, etc.)
- Manage courses and accounts
- Synthesize new resources (e.g. problem sheets) using LLMs

## Usage

[![asciicast](https://asciinema.org/a/pEzUGLWc55PfKzXmb282NqtDS.svg)](https://asciinema.org/a/pEzUGLWc55PfKzXmb282NqtDS?speed=2)

## Installation

Arch (not yet):
``yay -S python-canvy``

Basically anything else:

1. Install [uv](https://github.com/astral-sh/uv)
2. ``uv tool install canvy``

## Contribution

yes
